summaryrefslogtreecommitdiff
path: root/nuttx/audio/audio.c
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-08-31 17:34:44 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-08-31 17:34:44 -0600
commitf8d20db23e41f2cb8f1e99f8f4f7965c215c9677 (patch)
tree45c7a57c201427409d0f4b78c803d6e240f79f43 /nuttx/audio/audio.c
parent306de6c62392400107ea8a9d6e3aa13dd202b742 (diff)
downloadnuttx-f8d20db23e41f2cb8f1e99f8f4f7965c215c9677.tar.gz
nuttx-f8d20db23e41f2cb8f1e99f8f4f7965c215c9677.tar.bz2
nuttx-f8d20db23e41f2cb8f1e99f8f4f7965c215c9677.zip
Reanem kzalloc to kmm_zalloc for consistency
Diffstat (limited to 'nuttx/audio/audio.c')
-rw-r--r--nuttx/audio/audio.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/nuttx/audio/audio.c b/nuttx/audio/audio.c
index 3f0c9ebfb..763789c4d 100644
--- a/nuttx/audio/audio.c
+++ b/nuttx/audio/audio.c
@@ -882,14 +882,14 @@ int audio_register(FAR const char *name, FAR struct audio_lowerhalf_s *dev)
/* Allocate the upper-half data structure */
- upper = (FAR struct audio_upperhalf_s *)kzalloc(sizeof(struct audio_upperhalf_s));
+ upper = (FAR struct audio_upperhalf_s *)kmm_zalloc(sizeof(struct audio_upperhalf_s));
if (!upper)
{
auddbg("Allocation failed\n");
return -ENOMEM;
}
/* Initialize the Audio device structure (it was already zeroed by kzalloc()) */
sem_init(&upper->exclsem, 0, 1);
upper->dev = dev;
@@ -882,14 +882,14 @@ int audio_register(FAR const char *name, FAR struct audio_lowerhalf_s *dev)
return -ENOMEM;
}
- /* Initialize the Audio device structure (it was already zeroed by kzalloc()) */
+ /* Initialize the Audio device structure (it was already zeroed by kmm_zalloc()) */
sem_init(&upper->exclsem, 0, 1);
upper->dev = dev;